@@ -8,7 +8,7 @@ use warnings;
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-05-02'; # DATE
 our $DIST = 'Config-IOD-Reader'; # DIST
-our $VERSION = '0.344'; # VERSION
+our $VERSION = '0.345'; # VERSION
 
 use constant +{
     COL_V_ENCODING => 0, # either "!j"... or '"', '[', '{', '~'
@@ -556,7 +556,7 @@ Config::IOD::Base - Base class for Config::IOD and Config::IOD::Reader
 
 =head1 VERSION
 
-This document describes version 0.344 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2022-05-02.
+This document describes version 0.345 of Config::IOD::Base (from Perl distribution Config-IOD-Reader), released on 2022-05-02.
 
 =head1 EXPRESSION
 
@@ -782,10 +782,16 @@ B<NOTE: Turning this setting on violates IOD specification.>
 Emit warning if configuration contains key line like these:
 
  foo=>"bar"
- foo => bar,
+ foo => 123,
 
 which suggest user is assuming configuration is in Perl format instead of INI.
 
+If you enable this option, but happens to have a value that begins with ">", to
+avoid this warning you can quote the value first:
+
+ foo=">the value does begins with a greater-than sign"
+ bar=">the value does begins with a greater-than sign and ends with a comma,"
+
 =for END_BLOCK: attributes
 
 =head1 METHODS
